<?xml version='1.0' encoding="iso-8859-1"?>

<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	xmlns="http://www.w3.org/1999/xhtml">

<xsl:template name="block.charseq">
	<!--
		Mejora:
			1. La clase del elemento <div> que genera el elemento de bloque
			(itemizedlist, section, etc...) est constituida por el nombre del
			elemento y el valor del atributo role. As:
				<itemizedlist role="particular">
			se traduce en:
				<div class="itemizedlistparticular">
			De este modo, para hacer referencia a todas las listas provenientes
			de un elemento itemizedlist bastara incluir en el css:
				div[class*=itemizedlist] {...}
			y si se quiere particularizar para la lista de tipo "particular":
				div.itemizedlistparticular {...}
	-->
	<xsl:param name="element_name" select="'div'" />
	<xsl:param name="supclass" />
	<xsl:param name="add.elementname" select="1" />
	<xsl:param name="content" />
	
	<xsl:element name="{$element_name}">
		<xsl:if test="@id">
			<xsl:attribute name="id">
				<xsl:value-of select="@id" />
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="@dir">
			<xsl:attribute name="dir">
				<xsl:value-of select="@dir" />
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="$element_name='div' or @role or $supclass!=''">
			<xsl:attribute name="class">
				<xsl:variable name="divclass">
					<xsl:if test="$element_name = 'div' and $add.elementname = 1">
						<xsl:value-of select="local-name(.)" />
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="role">
					<xsl:if test="@role and $para.propagates.style != 0">
						<xsl:value-of select="@role" />
					</xsl:if>
				</xsl:variable>
					<xsl:value-of select="concat($divclass,$role,$supclass)" />
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="@lang or @xml:lang">
			<xsl:call-template name="language.attribute"/>
		</xsl:if>
		<xsl:copy-of select="$content" />
	</xsl:element>
</xsl:template>

<xsl:template match="attribution">
	<p class="{local-name(.)}"><xsl:apply-templates /></p>
</xsl:template>

<xsl:template match="blockquote">
	<xsl:call-template name="block.charseq">
		<xsl:with-param name="element_name" select="'blockquote'" />
		<xsl:with-param name="content">
			<xsl:apply-templates select="child::*[local-name(.)!='attribution']"/>
			<xsl:apply-templates select="attribution" />
		</xsl:with-param>
	</xsl:call-template>
</xsl:template>

</xsl:stylesheet>
