<?xml version='1.0' encoding="iso-8859-1"?>

<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	xmlns="http://www.w3.org/1999/xhtml">

	<xsl:template name="inline.charseq">
	<!--
		Mejoras:
			a) No crea un elemento <a> vaco para incluir el atributo id.
			b) Permite indicar cul es el elemento xhtml correspondiente a
				travs del parmetro "element_name".
				Por ejemplo, la plantilla de <quote> pasa como valor de
				element_name "q".
			c) Enriquece el atributo class, que est formado por la
				yuxtaposicin del nombre del elemento docbook (si la
				traduccin xhtml es <span> y el parmetro
				"add.elementname" vale 1), del atributo "role"
				(si phrase.propagates.style vale 1) y de otra cadena
				accesoria (parmetro "supclass"). La generacin de esta
				otra cadena accesoria se har, si se hace, en la plantilla
				del elemento docbook que hace uso de esta plantilla. Por
				ejemplo, la plantilla de <quote> pasa como valor de
				supclass la "profundidad" de la cita, esto es, el nmero
				de elementos cita que son antecesores del nodo cita actual.
				Por ejemplo, en una cita incluida dentro de otra cita,
				supclass vale 1.
	-->
		<xsl:param name="element_name" select="'span'" />
		<xsl:param name="supclass" />
		<xsl:param name="add.elementname" select="0" />
		
		<xsl:element name="{$element_name}">
			<xsl:if test="@id">
				<xsl:attribute name="id">
					<xsl:value-of select="@id" />
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@dir">
				<xsl:attribute name="dir">
					<xsl:value-of select="@dir" />
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="$element_name='span' or @role or $supclass!=''">
				<xsl:attribute name="class">
					<xsl:variable name="spanclass">
						<xsl:if test="$element_name='span' and $add.elementname=1">
							<xsl:value-of select="local-name(.)" />
						</xsl:if>
					</xsl:variable>
					<xsl:variable name="role">
						<xsl:if test="@role and $phrase.propagates.style != 0">
							<xsl:value-of select="@role" />
						</xsl:if>
					</xsl:variable>
					<xsl:value-of select="concat($spanclass,$role,$supclass)" />
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@lang or @xml:lang">
				<xsl:call-template name="language.attribute"/>
			</xsl:if>
			<xsl:call-template name="simple.xlink">
				<xsl:with-param name="content">
					<xsl:apply-templates/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:element>
	</xsl:template>

	<xsl:template match="phrase">
		<xsl:call-template name="inline.charseq" />
	</xsl:template>

	<xsl:template match="quote">
	<!-- El elemento "quote" de docbook se convierte en el "q" de xhtml -->
		<xsl:call-template name="inline.charseq">
			<xsl:with-param name="element_name" select="'q'" />
			<xsl:with-param name="supclass">
				<xsl:variable name="depth">
					<xsl:call-template name="dot.count">
						<xsl:with-param name="string"><xsl:number level="multiple"/></xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$depth &gt; 0">
					<xsl:value-of select="$depth" />
				</xsl:if>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>
