<?xml version='1.0' encoding="iso-8859-1"?>

<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	xmlns="http://www.w3.org/1999/xhtml">

<xsl:template match="itemizedlist">
	<xsl:call-template name="block.charseq">
		<xsl:with-param name="content">
			<xsl:if test="title">
				<xsl:call-template name="formal.object.heading"/>
			</xsl:if>
			<!-- Preserve order of PIs and comments -->
			<xsl:apply-templates select="*[not(self::listitem                   or self::title                   or self::titleabbrev)]                 |comment()[not(preceding-sibling::listitem)]                 |processing-instruction()[not(preceding-sibling::listitem)]"/>
			<ul>
				<xsl:if test="$css.decoration != 0">
					<xsl:attribute name="type">
						<xsl:call-template name="list.itemsymbol"/>
					</xsl:attribute>
				</xsl:if>
				<xsl:if test="@spacing='compact'">
					<xsl:attribute name="compact">
						<xsl:value-of select="@spacing"/>
					</xsl:attribute>
				</xsl:if>
				<xsl:apply-templates select="listitem                     |comment()[preceding-sibling::listitem]                     |processing-instruction()[preceding-sibling::listitem]"/>
			</ul>
		</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template match="orderedlist">
	<xsl:variable name="pi-start">
		<xsl:call-template name="dbhtml-attribute">
			<xsl:with-param name="pis" select="processing-instruction('dbhtml')"/>
			<xsl:with-param name="attribute" select="'start'"/>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:variable name="start">
		<xsl:choose>
			<xsl:when test="@continuation='continues'">
				<xsl:call-template name="orderedlist-starting-number"/>
			</xsl:when>
			<xsl:when test="$pi-start != ''">
				<xsl:value-of select="$pi-start"/>
			</xsl:when>
			<xsl:otherwise>1</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="numeration">
		<xsl:call-template name="list.numeration"/>
	</xsl:variable>
	
	<xsl:variable name="type">
		<xsl:choose>
			<xsl:when test="$numeration='arabic'">1</xsl:when>
			<xsl:when test="$numeration='loweralpha'">a</xsl:when>
			<xsl:when test="$numeration='lowerroman'">i</xsl:when>
			<xsl:when test="$numeration='upperalpha'">A</xsl:when>
			<xsl:when test="$numeration='upperroman'">I</xsl:when>
			<!-- What!? This should never happen -->
			<xsl:otherwise>
				<xsl:message>
					<xsl:text>Unexpected numeration: </xsl:text>
					<xsl:value-of select="$numeration"/>
				</xsl:message>
				<xsl:value-of select="1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="name">
		<xsl:call-template name="blockclass" />
	</xsl:variable>

<!--
	<div class="{$name}">
		<xsl:call-template name="anchor"/>
		
		<xsl:if test="title">
			<xsl:call-template name="formal.object.heading"/>
		</xsl:if>
		
		<xsl:apply-templates select="*[not(self::listitem                   or self::title                   or self::titleabbrev)]                 |comment()[not(preceding-sibling::listitem)]                 |processing-instruction()[not(preceding-sibling::listitem)]"/>
		
		<ol>
			<xsl:if test="$start != '1'">
				<xsl:attribute name="start">
					<xsl:value-of select="$start"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="$numeration != ''">
				<xsl:attribute name="type">
					<xsl:value-of select="$type"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@spacing='compact'">
				<xsl:attribute name="compact">
					<xsl:value-of select="@spacing"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="listitem                     |comment()[preceding-sibling::listitem]                     |processing-instruction()[preceding-sibling::listitem]"/>
		</ol>
	</div>
-->
	<xsl:call-template name="block.charseq">
		<xsl:with-param name="content">
			<xsl:if test="title">
				<xsl:call-template name="formal.object.heading"/>
			</xsl:if>
			<!-- Preserve order of PIs and comments -->
			<xsl:apply-templates select="*[not(self::listitem                   or self::title                   or self::titleabbrev)]                 |comment()[not(preceding-sibling::listitem)]                 |processing-instruction()[not(preceding-sibling::listitem)]"/>
			<ol>
				<xsl:if test="$start != '1'">
					<xsl:attribute name="start">
						<xsl:value-of select="$start"/>
					</xsl:attribute>
				</xsl:if>
				<xsl:if test="$numeration != ''">
					<xsl:attribute name="type">
						<xsl:value-of select="$type"/>
					</xsl:attribute>
				</xsl:if>
				<xsl:if test="@spacing='compact'">
					<xsl:attribute name="compact">
						<xsl:value-of select="@spacing"/>
					</xsl:attribute>
				</xsl:if>
				<xsl:apply-templates select="listitem                     |comment()[preceding-sibling::listitem]                     |processing-instruction()[preceding-sibling::listitem]"/>
			</ol>
		</xsl:with-param>
	</xsl:call-template>
</xsl:template>

</xsl:stylesheet>
